@@ -14,12 +14,12 @@ test_that("code check", {
 })
 
 test_that("date check from", {
-  chk <- tail(ubci_get("UPBIT.KRW-BTC", from = "2018-05-01"),1)$date
-  expect_equal(chk, as.Date("2018-05-01"))
+  chk <- tail(ubci_get("UPBIT.KRW-BTC", from = Sys.Date()-5),1)$date
+  expect_equal(chk, Sys.Date()-5)
 })
 
 test_that("date check to", {
-  chk <- head(ubci_get("UPBIT.KRW-BTC", to = "2018-05-01"),1)$date
-  expect_equal(chk, as.Date("2018-05-01"))
+  chk <- head(ubci_get("UPBIT.KRW-BTC", to = Sys.Date()-2),1)$date
+  expect_equal(chk, Sys.Date()-2)
 })
 
